# Notebook output stripper

A package that can be used to strip any notebook output cells. The stripper goes over the file line by line, so there is no memory concerns when stripping especially large notebooks.

Usage is simple:

    nb_output_stripper [input] [output]
